@@ -60,7 +60,7 @@ from typing import Iterable, Iterator, List, Optional, Union, overload
 
 # 3rd party
 import attr
-from apeye import URL
+from apeye_core import URL
 from click import echo
 from github3 import GitHub
 from github3.orgs import Organization
@@ -70,15 +70,15 @@ from github3.users import User
 from typing_extensions import Literal
 
 # this package
-from github3_utils.headers import LUKE_CAKE
+from github3_utils.headers import LUKE_CAGE
 
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 __license__: str = "MIT License"
-__version__: str = "0.6.1"
+__version__: str = "0.7.0"
 __email__: str = "dominic@davis-foster.co.uk"
 
-__all__ = [
+__all__ = (
 		"RateLimitExceeded",
 		"echo_rate_limit",
 		"get_user",
@@ -86,7 +86,7 @@ __all__ = [
 		"Impersonate",
 		"get_repos",
 		"iter_repos",
-		]
+		)
 
 
 class RateLimitExceeded(RuntimeError):
@@ -179,7 +179,7 @@ def protect_branch(branch: Branch, status_checks: Optional[List[str]] = None) ->
 	resp = branch._put(
 			str(URL(branch._api) / "protection"),
 			json=edit,
-			headers=LUKE_CAKE,
+			headers=LUKE_CAGE,
 			)
 
 	if branch._boolean(resp, 200, 404):
@@ -305,6 +305,7 @@ def iter_repos(
 	:param orgs: An iterable of organization names to fetch the repositories for.
 	"""
 
+	# pylint: disable=loop-invariant-statement
 	for user in users:
 		_user: Optional[User] = github.user(user)
 		if _user is None:
@@ -319,3 +320,4 @@ def iter_repos(
 			raise ValueError(f"No such organization {org}")
 
 		yield from get_repos(_org, full=False)
+	# pylint: enable=loop-invariant-statement
