@@ -41,7 +41,7 @@ from typing_extensions import Literal
 # this package
 from github3_utils.headers import MACHINE_MAN
 
-__all__ = ["ContextSwitcher", "iter_installed_repos", "make_footer_links"]
+__all__ = ("ContextSwitcher", "iter_installed_repos", "make_footer_links")
 
 
 @attr.s
@@ -127,6 +127,8 @@ def iter_installed_repos(
 	:param private_key_pem: The bytes of the private key for this GitHub App.
 	:param app_id: The integer identifier for this GitHub App.
 
+	.. latex:clearpage::
+
 	Either ``context_switcher`` or all of ``client``, ``private_key_pem`` and ``app_id`` must be provided.
 	"""
 
